

# class _VirtualLcd(object):
#     LCD_LINE_1 = 0
#     LCD_LINE_2 = 1
#
#     def lcd_init(self, *args):
#         pass


# noinspection PyClassHasNoInit
class VirtualLcd(object):
    # LCD = _VirtualLcd()
    LCD_LINE_1 = 0
    LCD_LINE_2 = 1

    def lcd_init(self, *args):
        pass

